Contributors
============

This package was originally based on `bobtemplates.niteoweb <https://github.com/niteoweb/bobtemplates.niteoweb>`_ and `bobtemplates.ecreall <https://github.com/cedricmessiant/bobtemplates.ecreall>`_

- Maik Derstappen [MrTango]
- Philip Bauer [pbauer]
- Cédric Messiant [cedricmessiant]
- Vincent Fretin [vincentfretin]
- Thomas Desvenain [thomasdesvenain]
- Domen Kožar [iElectric]
- Nejc Zupan [zupo]
- Patrick Gerken [do3cc]
- Timo Stollenwerk [timo]
- Johannes Raggam [thet]
- Sven Strack [svx]
- Héctor Velarde [hvelarde]
- Aurore Mariscal [AuroreMariscal]
- Víctor Fernández de Alba [sneridagh]
- Alexander Loechel [loechel]
- Peter Holzer [agitator]
- Manuel Reinhardt [reinhardt]
